@@ -53,7 +53,12 @@
 enum base_type { BIN, OCT, DEC, HEX, MAXBASES };
 
 /* Calculator modes. */
-enum mode_type { BASIC, ADVANCED, FINANCIAL, SCIENTIFIC, MAXMODES };
+enum mode_type { BASIC, 
+                 ADVANCED,
+                 FINANCIAL,
+                 SCIENTIFIC,
+                 PROGRAMMING,
+                 MAXMODES };
 
 /* Number display mode. */
 enum num_type { ENG, FIX, SCI, MAXDISPMODES };
@@ -103,6 +108,7 @@ enum
     KEY_FINC_CTRM,
     KEY_FINC_DDB,
     KEY_FINC_FV,
+    KEY_FINC_GPM,
     KEY_FINC_PMT,
     KEY_FINC_PV,
     KEY_FINC_RATE,
@@ -112,6 +118,10 @@ enum
     KEY_SHIFT,
     KEY_STORE, KEY_RECALL, KEY_EXCHANGE,
     KEY_SET_ACCURACY,
+    KEY_SET_BASE,
+    KEY_SET_NUMBERTYPE,
+    KEY_UNDO,
+    KEY_REDO,
     KEY_CONSTANT,
     KEY_FUNCTION,
     NKEYS
@@ -139,7 +149,6 @@ enum
 #define MAX_CONSTANTS 10
 #define MAX_FUNCTIONS 10
 #define MAX_REGISTERS 10         /* Maximum number of memory registers. */
-#define MAXBITCALC     2          /* Choices for bitcalculating */
 
 #ifndef MIN
 #define MIN(x,y)       ((x) < (y) ? (x) : (y))
@@ -171,8 +180,6 @@ struct button {
 };
 
 struct calcVars {                      /* Calctool variables and options. */
-    int current;                       /* Current button/character pressed. */
-  
     char *appname;                     /* Application name for resources. */
     char *home;                        /* Pathname for users home directory. */
     char *progname;                    /* Name of this program. */
