@@ -42,7 +42,7 @@
 char *Rbstr[MAXBASES]     = { "BIN", "OCT", "DEC", "HEX" };
 char *Rdstr[MAXDISPMODES] = { "ENG", "FIX", "SCI" };
 char *Rmstr[MAXMODES]     = { "BASIC", "ADVANCED", "FINANCIAL", 
-                              "SCIENTIFIC" };
+                              "SCIENTIFIC", "PROGRAMMING" };
 char *Rtstr[MAXTRIGMODES] = { "DEG", "GRAD", "RAD" };
 
 static GConfClient *client = NULL;
@@ -52,7 +52,7 @@ char *
 get_resource(char *key)
 {
     char key_name[MAXLINE];
-    SNPRINTF(key_name, MAXLINE, "/apps/gcalctool/%s", key);
+    SNPRINTF(key_name, MAXLINE, "/apps/%s/%s", v->appname, key);
     return(gconf_client_get_string(client, key_name, NULL));
 }
 
@@ -61,7 +61,7 @@ void
 set_resource(char *key, char *value)
 {
     char key_name[MAXLINE];
-    SNPRINTF(key_name, MAXLINE, "/apps/gcalctool/%s", key);    
+    SNPRINTF(key_name, MAXLINE, "/apps/%s/%s", v->appname, key);    
     gconf_client_set_string(client, key_name, value, NULL);
 }
 
@@ -250,7 +250,7 @@ read_resources()    /* Read all possible resources from the database. */
     for (i = 0; i < MAX_REGISTERS; i++) {
         SNPRINTF(key, MAXLINE, "register%d", i);
         if (get_str_resource(key, str)) {
-            MPstr_to_num(str, DEC, v->MPmvals[i]);
+            MPstr_to_num(str, 10, v->MPmvals[i]);
         }
     }
 
@@ -333,7 +333,10 @@ read_resources()    /* Read all possible resources from the database. */
 void
 resources_init()        /* Load gconf configuration database for gcalctool. */
 { 
+    char str[MAXLINE];
+
     assert(client == NULL);
+    SNPRINTF(str, MAXLINE, "/apps/%s", v->appname);
     client = gconf_client_get_default();
-    gconf_client_add_dir(client, "/apps/gcalctool", GCONF_CLIENT_PRELOAD_NONE, NULL);
+    gconf_client_add_dir(client, str, GCONF_CLIENT_PRELOAD_NONE, NULL);
 }
