@@ -32,10 +32,8 @@
 #define R_TRIG     "trigtype"
 #define R_ZEROES   "showzeroes"
 #define R_TSEP     "showthousands"
-#define R_BITCALC  "bitcalculating"
 #define R_XPOS     "xposition"
 #define R_YPOS     "yposition"
-#define R_CHMODE   "warn_change_mode"
 
 extern char *Rbstr[];          /* Base mode X resource strings. */
 extern char *Rdstr[];          /* Display mode X resource strings. */
